tlslite.utils.tripledes.TripleDES

Package tlslite :: Package utils :: Module tripledes :: Class TripleDES |
[hide private]
[frames] | no frames]

# Class TripleDES

source code

Known Subclasses:
  - openssl_tripledes.OpenSSL_TripleDES
  - , pycrypto_tripledes.PyCrypto_TripleDES

Instance Methods | [hide private]
__init__(self, key, mode, IV, implementation) | source code
decrypt(self, ciphertext) | source code
encrypt(self, plaintext) | source code